'use client'

import { useState } from 'react'
import { FiSave } from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { categoryService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { useRouter } from 'next/navigation'
import Modal from '@/components/ui/Modal'

export default function AddCategoryPage() {
  const { user } = useUser()
  const [categoryName, setCategoryName] = useState('')
  const [success, setSuccess] = useState(false)
  const [error, setError] = useState<string | null>(null)
  const router = useRouter()

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    try {
      await categoryService.store(categoryName, user?.token || '')
      setSuccess(true)
      setTimeout(() => {
        router.push('/dashboard/categories')
      }, 1500)
    } catch (error) {
      setError(error instanceof Error ? error.message : 'Bir hata oluştu')
    }
  }

  return (
    <DashboardLayout>
      <div className="w-full mx-auto">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg border border-slate-200/50 dark:border-slate-700/50">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <h2 className="text-xl font-bold text-slate-800 dark:text-white">
              Yeni Kategori Ekle
            </h2>
            <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
              Yeni bir kategori eklemek için aşağıdaki formu doldurun
            </p>
          </div>

          <form onSubmit={handleSubmit} className="p-6 space-y-6">
            <div>
              <label htmlFor="categoryName" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                Kategori Adı
              </label>
              <input
                id="categoryName"
                type="text"
                value={categoryName}
                onChange={(e) => setCategoryName(e.target.value)}
                className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                         bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                         text-slate-800 dark:text-white
                         focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                         transition-all placeholder-slate-400 dark:placeholder-slate-500"
                placeholder="Örn: Sıcak İçecekler"
                required
              />
            </div>

            <div className="flex justify-end">
              <button
                type="submit"
                className="px-6 py-2.5 text-sm font-medium text-white 
                         bg-gradient-to-r from-fuchsia-500 to-purple-600 
                         rounded-xl hover:opacity-90 transition-all 
                         shadow-lg shadow-fuchsia-500/25
                         flex items-center gap-2"
              >
                <FiSave className="w-4 h-4" />
                <span>Kaydet</span>
              </button>
            </div>
          </form>
        </div>
      </div>
      <Modal
        isOpen={success}
        onClose={() => setSuccess(false)}
        title="Başarılı"
        message="Kategori başarıyla eklendi yönlendiriliyorsunuz..."
      />
      {error && (
        <div className="text-red-500 text-sm mt-2">
          {error}
        </div>
      )}
    </DashboardLayout>
  )
} 